server

package
v0.0.0-...-6d126c1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package server starts the API server

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	*fiber.App
	Addr string
}

func New

func New(service service.Service) *Server

Directories

Path Synopsis
Package dto forms the bridge between the api data and the internal models
Package dto forms the bridge between the api data and the internal models

Jump to