tui

package
v0.0.0-...-6d126c1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package tui provides utilities for working with the terminal.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TUI

type TUI struct {
	// contains filtered or unexported fields
}

TUI represent a terminal instance

func New

func New(screen screen.Screen) *TUI

New creates a new tui instance

func (*TUI) Init

func (t *TUI) Init() tea.Cmd

Init initializes the tui

func (*TUI) Update

func (t *TUI) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update updates the tui

func (*TUI) View

func (t *TUI) View() string

View returns the tui view

Directories

Path Synopsis
components
bar
Package bar provides an animated progress bar
Package bar provides an animated progress bar
stopwatch
Package stopwatch provides a simple stopwatch component
Package stopwatch provides a simple stopwatch component
Package screen contains the interface for a screen
Package screen contains the interface for a screen
cammie
Package cammie returns the screen containing the cammie messages and other stats
Package cammie returns the screen containing the cammie messages and other stats
song
Package song contains the screen displaying the song view
Package song contains the screen displaying the song view
Package theme contains the tui theme variables
Package theme contains the tui theme variables
Package view contains all the different views for the tui
Package view contains all the different views for the tui
event
Package event provides the functions to draw all the upcoming zeus events on a TUI
Package event provides the functions to draw all the upcoming zeus events on a TUI
gamification
Package gamification provides the functions to draw an overview of gamification on a TUI
Package gamification provides the functions to draw an overview of gamification on a TUI
message
Package message provides the functions to draw all the cammie messages on a TUI
Package message provides the functions to draw all the cammie messages on a TUI
song
Package song provides the functions to draw an overview of the song integration
Package song provides the functions to draw an overview of the song integration
tap
Package tap provides the functions to draw an overview of the recent tap orders on a TUI
Package tap provides the functions to draw an overview of the recent tap orders on a TUI
zess
Package zess provides the functions to draw an overview of the zess scans on a TUI
Package zess provides the functions to draw an overview of the zess scans on a TUI

Jump to