screen

package
v0.0.0-...-6d126c1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package screen contains the interface for a screen

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Screen

type Screen interface {
	Init() tea.Cmd
	Update(tea.Msg) (Screen, tea.Cmd)
	View() string
	GetUpdateViews() []view.UpdateData
	GetSizeMsg() tea.Msg
}

Directories

Path Synopsis
Package cammie returns the screen containing the cammie messages and other stats
Package cammie returns the screen containing the cammie messages and other stats
Package song contains the screen displaying the song view
Package song contains the screen displaying the song view

Jump to