Documentation
¶
Overview ¶
Package view contains all the different views for the tui
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetOuterHeight ¶
GetOuterHeight returns the outer border size of a lipgloss Style
func GetOuterWidth ¶
GetOuterWidth returns the outer border size of a lipgloss Style
Types ¶
type MsgSize ¶
MsgSize is a message to let a view know its size The key of Sizes is the name of a view
Directories
¶
| Path | Synopsis |
|---|---|
|
Package event provides the functions to draw all the upcoming zeus events on a TUI
|
Package event provides the functions to draw all the upcoming zeus events on a TUI |
|
Package gamification provides the functions to draw an overview of gamification on a TUI
|
Package gamification provides the functions to draw an overview of gamification on a TUI |
|
Package message provides the functions to draw all the cammie messages on a TUI
|
Package message provides the functions to draw all the cammie messages on a TUI |
|
Package song provides the functions to draw an overview of the song integration
|
Package song provides the functions to draw an overview of the song integration |
|
Package tap provides the functions to draw an overview of the recent tap orders on a TUI
|
Package tap provides the functions to draw an overview of the recent tap orders on a TUI |
|
Package zess provides the functions to draw an overview of the zess scans on a TUI
|
Package zess provides the functions to draw an overview of the zess scans on a TUI |
Click to show internal directories.
Click to hide internal directories.